@@ -19,11 +19,11 @@ def make_prediction(
 
     data = pd.DataFrame(input_data)
     validated_data, errors = validate_inputs(input_data=data)
-    results = {"predictions": None, "version": _version, "errors": errors}
+    results = {"predictions": [], "version": _version, "errors": errors}
 
     if not errors:
-        predictions = _titanic_pipe.predict(
-            X=validated_data[config.model_config.features]
+        predictions = list(
+            _titanic_pipe.predict(X=validated_data[config.model_config.features])
         )
         results = {
             "predictions": predictions,
